@@ -274,9 +274,14 @@ void AssetParameterModel::setParameter(const QString &name, int value, bool upda
     if (m_builtIn) {
         bool isDisabled = m_asset->get_int("disable") == 1;
         if (!isDisabled) {
-            if (isDefault() && m_assetId != QLatin1String("volume")) {
+            if (isDefault()) {
                 m_asset->set("disable", 1);
             }
+        } else {
+            // Asset disabled
+            if (!isDefault()) {
+                m_asset->clear("disable");
+            }
         }
     }
     if (m_fixedParams.count(name) == 0) {
@@ -432,7 +437,6 @@ void AssetParameterModel::internalSetParameter(const QString name, const QString
             }
         }
     }
-    // qDebug() << " = = SET EFFECT PARAM: " << name << " = " << m_asset->get(name.toLatin1().constData());
 }
 
 const QChar AssetParameterModel::getKeyframeType(const QString keyframeString)
@@ -457,9 +461,14 @@ void AssetParameterModel::setParameter(const QString &name, const QString &param
     if (m_builtIn && !groupedCommand) {
         bool isDisabled = m_asset->get_int("disable") == 1;
         if (!isDisabled) {
-            if (isDefault() && m_assetId != QLatin1String("volume")) {
+            if (isDefault()) {
                 m_asset->set("disable", 1);
             }
+        } else {
+            // Asset disabled
+            if (!isDefault()) {
+                m_asset->clear("disable");
+            }
         }
     }
     bool updateChildRequired = true;
@@ -709,7 +718,6 @@ const QString AssetParameterModel::framesToTime(int t) const
 
 int AssetParameterModel::rowCount(const QModelIndex &parent) const
 {
-    // qDebug() << "===================================================== Requested rowCount" << parent << m_rows.size();
     if (parent.isValid()) return 0;
     return m_rows.size();
 }
