@@ -17,6 +17,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "kdenlivesettings.h"
 #include "lib/audio/audioStreamInfo.h"
 #include "profiles/profilemodel.hpp"
+#include "xml/xml.hpp"
 
 #include "core.h"
 #include "kdenlive_debug.h"
@@ -27,7 +28,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 std::shared_ptr<Mlt::Producer> ClipController::mediaUnavailable;
 
-ClipController::ClipController(const QString &clipId, const std::shared_ptr<Mlt::Producer> &producer)
+ClipController::ClipController(const QString &clipId, const std::shared_ptr<Mlt::Producer> &producer, const QDomElement &description)
     : selectedEffectIndex(1)
     , m_audioThumbCreated(false)
     , m_producerLock(QReadWriteLock::Recursive)
@@ -64,7 +65,12 @@ ClipController::ClipController(const QString &clipId, const std::shared_ptr<Mlt:
         checkAudioVideo();
     } else {
         m_producerLock.lockForWrite();
-        m_controlUuid = QUuid::createUuid();
+        if (Xml::hasXmlProperty(description, QStringLiteral("kdenlive:control_uuid"))) {
+            const QString uuid = Xml::getXmlProperty(description, QStringLiteral("kdenlive:control_uuid"));
+            m_controlUuid = QUuid(uuid);
+        } else {
+            m_controlUuid = QUuid::createUuid();
+        }
     }
 }
 
@@ -649,8 +655,16 @@ double ClipController::originalFps() const
     if (!m_properties) {
         return 0;
     }
-    QString propertyName = QStringLiteral("meta.media.%1.stream.frame_rate").arg(m_videoIndex);
-    return m_properties->get_double(propertyName.toUtf8().constData());
+    double fps = 0.;
+    int fps_den = m_properties->get_int("meta.media.frame_rate_den");
+    if (fps_den > 0) {
+        fps = m_properties->get_double("meta.media.frame_rate_num") / fps_den;
+    }
+    if (fps == 0. && m_videoIndex > -1) {
+        QString propertyName = QStringLiteral("meta.media.%1.stream.frame_rate").arg(m_videoIndex);
+        return m_properties->get_double(propertyName.toUtf8().constData());
+    }
+    return fps;
 }
 
 QString ClipController::videoCodecProperty(const QString &property) const
@@ -1153,10 +1167,23 @@ const QString ClipController::getOriginalUrl()
     return path;
 }
 
+bool ClipController::supportsProxy() const
+{
+    switch (clipType()) {
+        case ClipType::Video:
+        case ClipType::AV:
+        case ClipType::Image:
+        case ClipType::Playlist:
+        case ClipType::SlideShow:
+            return true;
+        default:
+            return false;
+    }
+}
+
 bool ClipController::hasProxy() const
 {
     QString proxy = getProducerProperty(QStringLiteral("kdenlive:proxy"));
-    // qDebug()<<"::: PROXY: "<<proxy<<" = "<<getProducerProperty(QStringLiteral("resource"));
     return proxy.size() > 2 && proxy == getProducerProperty(QStringLiteral("resource"));
 }
 
