@@ -51,12 +51,19 @@ ClipModel::ClipModel(const std::shared_ptr<TimelineModel> &parent, std::shared_p
     }
     QObject::connect(m_effectStack.get(), &EffectStackModel::dataChanged, m_effectStack.get(),
                      [&](const QModelIndex &, const QModelIndex &, const QVector<int> &roles) {
-                         qDebug() << "// GOT CLIP STACK DATA CHANGE: " << roles;
                          if (m_currentTrackId != -1) {
                              if (auto ptr = m_parent.lock()) {
                                  QModelIndex ix = ptr->makeClipIndexFromID(m_id);
                                  Q_EMIT ptr->dataChanged(ix, ix, roles);
-                                 qDebug() << "// GOT CLIP STACK DATA CHANGE DONE: " << ix << " = " << roles;
+                             }
+                         }
+                     });
+    QObject::connect(m_effectStack.get(), &EffectStackModel::customDataChanged, m_effectStack.get(),
+                     [&](const QModelIndex &, const QModelIndex &, const QVector<int> &roles) {
+                         if (m_currentTrackId != -1) {
+                             if (auto ptr = m_parent.lock()) {
+                                 QModelIndex ix = ptr->makeClipIndexFromID(m_id);
+                                 Q_EMIT ptr->dataChanged(ix, ix, roles);
                              }
                          }
                      });
@@ -156,8 +163,6 @@ ClipModel::~ClipModel() = default;
 bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool logUndo, bool hasMix)
 {
     QWriteLocker locker(&m_lock);
-    // qDebug() << "RESIZE CLIP" << m_id << "target size=" << size << "right=" << right << "endless=" << m_endlessResize << "length" <<
-    // m_producer->get_length()<<" > "<<m_producer->get("kdenlive:duration")<<" = "<<m_producer->get("kdenlive:maxduration");
     int maxDuration = m_producer->get_length();
     if (!m_endlessResize && (size <= 0 || size > maxDuration) && !hasTimeRemap()) {
         return false;
@@ -185,7 +190,6 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
     } else {
         in += delta;
     }
-    // qDebug() << "Resize facts delta =" << delta << "old in" << old_in << "old_out" << old_out << "in" << in << "out" << out;
     std::function<bool(void)> track_operation = []() { return true; };
     std::function<bool(void)> track_reverse = []() { return true; };
     int outPoint = out;
@@ -351,7 +355,7 @@ bool ClipModel::requestSlip(int offset, Fun &undo, Fun &redo, bool logUndo)
     Q_ASSERT(outPoint < m_producer->get_length());
     Q_ASSERT(inPoint >= 0);
     Q_ASSERT(inPoint <= m_producer->get_length() - m_producer->get_playtime());
-    Q_ASSERT(inPoint < outPoint);
+    Q_ASSERT(inPoint <= outPoint);
     Q_ASSERT(out - in == outPoint - inPoint);
 
     if (m_currentTrackId != -1) {
@@ -722,6 +726,17 @@ int ClipModel::getPlaytime() const
     return m_producer->get_playtime();
 }
 
+int64_t ClipModel::getStartTimecodeOffset() const
+{
+    READ_LOCK();
+    auto binClip = pCore->projectItemModel()->getClipByBinID(m_binClipId);
+    int recTC = binClip->getStartTimecode();
+    if (recTC >= 0) {
+        return recTC + getIn();
+    }
+    return -1;
+}
+
 void ClipModel::setTimelineEffectsEnabled(bool enabled)
 {
     QWriteLocker locker(&m_lock);
@@ -1105,7 +1120,7 @@ std::shared_ptr<MarkerListModel> ClipModel::getMarkerModel() const
 int ClipModel::audioChannels() const
 {
     READ_LOCK();
-    return pCore->projectItemModel()->getClipByBinID(m_binClipId)->audioChannels();
+    return pCore->projectItemModel()->getClipByBinID(m_binClipId)->audioChannels(audioStream());
 }
 
 bool ClipModel::audioMultiStream() const
@@ -1607,3 +1622,18 @@ void ClipModel::setActiveEffect(int row)
 {
     m_effectStack->setActiveEffect(row);
 }
+
+bool ClipModel::hasDisabledBuiltInTransform()
+{
+    return m_effectStack->hasDisabledBuiltInTransform();
+}
+
+void ClipModel::refreshAVInfo()
+{
+    std::shared_ptr<ProjectClip> binClip = pCore->projectItemModel()->getClipByBinID(m_binClipId);
+    if (binClip) {
+        m_canBeVideo = binClip->hasVideo();
+        m_canBeAudio = binClip->hasAudio();
+        refreshProducerFromBin(m_currentTrackId);
+    }
+}
